# PYRSM

Python functions and classes for Customer Analytics at the Rady School of Management (RSM), University of California, San Diego (UCSD)

## Install instructions

If you have python and UV installed you can use the below to install the latest version of `pyrsm` in a project folder:

```bash
mkdir ~/project
cd ~/project
uv init .
uv venv --python 3.12
source .venv/bin/activate
uv add pyrsm
```

&copy; Vincent Nijs (2025) <a rel="license" href="https://creativecommons.org/licenses/by-nc-sa/4.0/" target="_blank"><img alt="Creative Commons License" style="border-width: 0" src="images/by-nc-sa.png"/></a>
